@@ -1,5 +1,5 @@
 /*  GNU Ocrad - Optical Character Recognition program
-    Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009
+    Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010
     Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
@@ -36,11 +36,11 @@
 namespace {
 
 void add_line( std::vector< Textline * > & textlinep_vector ) throw()
-  { textlinep_vector.push_back( new Textline() ); }
+  { textlinep_vector.push_back( new Textline ); }
 
 
 void insert_line( std::vector< Textline * > & textlinep_vector, int i ) throw()
-  { textlinep_vector.insert( textlinep_vector.begin() + i, new Textline() ); }
+  { textlinep_vector.insert( textlinep_vector.begin() + i, new Textline ); }
 
 
 void delete_line( std::vector< Textline * > & textlinep_vector, int i ) throw()
@@ -95,13 +95,13 @@ Textblock::Textblock( const Rectangle & page, const Rectangle & block,
                       std::vector< Blob * > & blobp_vector ) throw()
   : Rectangle( block )
   {
-  // make cuts
   std::vector< Blob * > pending;
   std::vector< Blob * > pending_tall;
   std::vector< Blob * > pending_short;
+
   for( unsigned int begin = 0, end = 0; end < blobp_vector.size(); begin = end )
     {
-    int botmax = blobp_vector[begin]->bottom();
+    int botmax = blobp_vector[begin]->bottom();		// make cuts
     while( ++end < blobp_vector.size() )
       {
       if( blobp_vector[end]->top() > botmax ) break;
@@ -253,19 +253,18 @@ Textblock::Textblock( const Rectangle & page, const Rectangle & block,
     }
 
   // remove clipped lines at top or bottom of page
-  if( textlines() )
+  if( textlines() > 2 )
     {
-    const Textline & l = *tlpv[textlines()-1];
-    for( int i = 0, c = 0; i < l.characters(); ++i )
-      if( l.character( i ).bottom() >= page.bottom() && 2 * ++c >= l.characters() )
+    const Textline * lp = tlpv[textlines()-1];
+    for( int i = 0, c = 0; i < lp->characters(); ++i )
+      if( lp->character( i ).bottom() >= page.bottom() &&
+          2 * ++c >= lp->characters() )
         { delete_line( tlpv, textlines() - 1 ); break; }
-    }
-  if( textlines() )
-    {
-    const Textline & l = *tlpv[0];
+
+    lp = tlpv[0];
     const int t = std::max( page.top(), 1 );
-    for( int i = 0, c = 0; i < l.characters(); ++i )
-      if( l.character( i ).top() <= t && 2 * ++c >= l.characters() )
+    for( int i = 0, c = 0; i < lp->characters(); ++i )
+      if( lp->character( i ).top() <= t && 2 * ++c >= lp->characters() )
         { delete_line( tlpv, 0 ); break; }
     }
 
@@ -407,6 +406,14 @@ void Textblock::recognize( const Charset & charset, const Filter & filter ) thro
   }
 
 
+const Textline & Textblock::textline( int i ) const throw()
+  {
+  if( i < 0 || i >= textlines() )
+    Ocrad::internal_error( "line, index out of bounds" );
+  return *tlpv[i];
+  }
+
+
 int Textblock::characters() const throw()
   {
   int total = 0;
@@ -415,14 +422,6 @@ int Textblock::characters() const throw()
   return total;
   }
 
-/*
-Textline & Textblock::textline( int i ) const throw()
-  {
-  if( i < 0 || i >= textlines() )
-    Ocrad::internal_error( "line, index out of bounds" );
-  return *tlpv[i];
-  }
-*/
 
 void Textblock::print( const Control & control ) const throw()
   {
